summaryrefslogtreecommitdiff
path: root/indra/llmessage/llextendedstatus.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/llmessage/llextendedstatus.h')
-rw-r--r--indra/llmessage/llextendedstatus.h64
1 files changed, 30 insertions, 34 deletions
diff --git a/indra/llmessage/llextendedstatus.h b/indra/llmessage/llextendedstatus.h
index 8ce173d1ff..9923d73c1a 100644
--- a/indra/llmessage/llextendedstatus.h
+++ b/indra/llmessage/llextendedstatus.h
@@ -28,40 +28,36 @@
#ifndef LL_LLEXTENDEDSTATUS_H
#define LL_LLEXTENDEDSTATUS_H
-
-typedef S32 LLExtStat;
-
-
-// Status provider groups - Top bits indicate which status type it is
-// Zero is common status code (next section)
-const LLExtStat LL_EXSTAT_CURL_RESULT = 1L<<30; // serviced by curl - use 1L if we really implement the below
-const LLExtStat LL_EXSTAT_RES_RESULT = 2L<<30; // serviced by resident copy
-const LLExtStat LL_EXSTAT_VFS_RESULT = 3L<<30; // serviced by vfs
-
-
-// Common Status Codes
-//
-const LLExtStat LL_EXSTAT_NONE = 0x00000; // No extra info here - sorry!
-const LLExtStat LL_EXSTAT_NULL_UUID = 0x10001; // null asset ID
-const LLExtStat LL_EXSTAT_NO_UPSTREAM = 0x10002; // attempt to upload without a valid upstream method/provider
-const LLExtStat LL_EXSTAT_REQUEST_DROPPED = 0x10003; // request was dropped unserviced
-const LLExtStat LL_EXSTAT_NONEXISTENT_FILE = 0x10004; // trying to upload a file that doesn't exist
-const LLExtStat LL_EXSTAT_BLOCKED_FILE = 0x10005; // trying to upload a file that we can't open
-
-
-// curl status codes:
-//
-// Mask off LL_EXSTAT_CURL_RESULT for original result and
-// see: libraries/include/curl/curl.h
-
-
-// Memory-Resident status codes:
-// None at present
-
-
-// VFS status codes:
-const LLExtStat LL_EXSTAT_VFS_CACHED = LL_EXSTAT_VFS_RESULT | 0x0001;
-const LLExtStat LL_EXSTAT_VFS_CORRUPT = LL_EXSTAT_VFS_RESULT | 0x0002;
+enum class LLExtStat: uint32_t
+{
+ // Status provider groups - Top bits indicate which status type it is
+ // Zero is common status code (next section)
+ CURL_RESULT = 1UL<<30, // serviced by curl - use 1L if we really implement the below
+ RES_RESULT = 2UL<<30, // serviced by resident copy
+ VFS_RESULT = 3UL<<30, // serviced by vfs
+
+
+ // Common Status Codes
+ //
+ NONE = 0x00000, // No extra info here - sorry!
+ NULL_UUID = 0x10001, // null asset ID
+ NO_UPSTREAM = 0x10002, // attempt to upload without a valid upstream method/provider
+ REQUEST_DROPPED = 0x10003, // request was dropped unserviced
+ NONEXISTENT_FILE= 0x10004, // trying to upload a file that doesn't exist
+ BLOCKED_FILE = 0x10005, // trying to upload a file that we can't open
+
+ // curl status codes:
+ //
+ // Mask off CURL_RESULT for original result and
+ // see: libraries/include/curl/curl.h
+
+ // Memory-Resident status codes:
+ // None at present
+
+ // VFS status codes:
+ VFS_CACHED = VFS_RESULT | 0x0001,
+ VFS_CORRUPT = VFS_RESULT | 0x0002,
+};
#endif // LL_LLEXTENDEDSTATUS_H